pub struct FinancialConnectionsAuthorization {
pub id: FinancialConnectionsAuthorizationId,
pub institution_name: String,
pub livemode: bool,
pub status: FinancialConnectionsAuthorizationStatus,
pub status_details: BankConnectionsResourceAuthorizationStatusDetails,
}Expand description
An Authorization represents the set of credentials used to connect a group of Financial Connections Accounts.
Fields
id: FinancialConnectionsAuthorizationIdUnique identifier for the object.
institution_name: StringThe name of the institution that this authorization belongs to.
livemode: boolIf the object exists in live mode, the value is true.
If the object exists in test mode, the value is false.
status: FinancialConnectionsAuthorizationStatusThe status of the connection to the Authorization.
status_details: BankConnectionsResourceAuthorizationStatusDetailsTrait Implementations
Sourceimpl Clone for FinancialConnectionsAuthorization
impl Clone for FinancialConnectionsAuthorization
Sourcefn clone(&self) -> FinancialConnectionsAuthorization
fn clone(&self) -> FinancialConnectionsAuthorization
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for FinancialConnectionsAuthorization
Sourceimpl FromValueOpt for FinancialConnectionsAuthorization
impl FromValueOpt for FinancialConnectionsAuthorization
fn from_value(v: Value) -> Option<Self>
impl StructuralPartialEq for FinancialConnectionsAuthorization