pub struct GelatoSessionDocumentOptions {
pub allowed_types: Option<Vec<GelatoSessionDocumentOptionsAllowedTypes>>,
pub require_id_number: Option<bool>,
pub require_live_capture: Option<bool>,
pub require_matching_selfie: Option<bool>,
}Fields
allowed_types: Option<Vec<GelatoSessionDocumentOptionsAllowedTypes>>Array of strings of allowed identity document types. If the provided identity document isn’t one of the allowed types, the verification check will fail with a document_type_not_allowed error code.
require_id_number: Option<bool>Collect an ID number and perform an ID number check with the document’s extracted name and date of birth.
require_live_capture: Option<bool>Disable image uploads, identity document images have to be captured using the device’s camera.
require_matching_selfie: Option<bool>Capture a face image and perform a selfie check comparing a photo ID and a picture of your user’s face. Learn more.