pub struct GelatoSessionLastError {
pub code: Option<GelatoSessionLastErrorCode>,
pub reason: Option<String>,
}Expand description
Shows last VerificationSession error
Fields
code: Option<GelatoSessionLastErrorCode>A short machine-readable string giving the reason for the verification or user-session failure.
reason: Option<String>A message that explains the reason for verification or user-session failure.